
#ifndef KUSERFEEDBACKWIDGETS_EXPORT_H
#define KUSERFEEDBACKWIDGETS_EXPORT_H

#ifdef KUSERFEEDBACKWIDGETS_STATIC_DEFINE
#  define KUSERFEEDBACKWIDGETS_EXPORT
#  define KUSERFEEDBACKWIDGETS_NO_EXPORT
#else
#  ifndef KUSERFEEDBACKWIDGETS_EXPORT
#    ifdef KF6UserFeedbackWidgets_EXPORTS
        /* We are building this library */
#      define KUSERFEEDBACKWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KUSERFEEDBACKWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KUSERFEEDBACKWIDGETS_NO_EXPORT
#    define KUSERFEEDBACKWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KUSERFEEDBACKWIDGETS_DECL_DEPRECATED
#  define KUSERFEEDBACKWIDGETS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_EXPORT
#  define KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_EXPORT KUSERFEEDBACKWIDGETS_EXPORT KUSERFEEDBACKWIDGETS_DECL_DEPRECATED
#endif

#ifndef KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_NO_EXPORT KUSERFEEDBACKWIDGETS_NO_EXPORT KUSERFEEDBACKWIDGETS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KUSERFEEDBACKWIDGETS_NO_DEPRECATED
#    define KUSERFEEDBACKWIDGETS_NO_DEPRECATED
#  endif
#endif
#include <kuserfeedback_version.h>

#undef KUSERFEEDBACKWIDGETS_DECL_DEPRECATED
#define KUSERFEEDBACKWIDGETS_DECL_DEPRECATED [[deprecated]]

#undef KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_EXPORT
#define KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_EXPORT KUSERFEEDBACKWIDGETS_EXPORT KUSERFEEDBACKWIDGETS_DECL_DEPRECATED

#undef KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_NO_EXPORT
#define KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_NO_EXPORT KUSERFEEDBACKWIDGETS_NO_EXPORT KUSERFEEDBACKWIDGETS_DECL_DEPRECATED

#define KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_TEXT(text) [[deprecated(text)]]

/* Take any defaults from group settings */
#if !defined(KUSERFEEDBACKWIDGETS_NO_DEPRECATED) && !defined(KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KUSERFEEDBACKWIDGETS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KUSERFEEDBACKWIDGETS_NO_DEPRECATED_WARNINGS) && !defined(KUSERFEEDBACKWIDGETS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KUSERFEEDBACKWIDGETS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KUSERFEEDBACKWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KUSERFEEDBACKWIDGETS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KUSERFEEDBACKWIDGETS_NO_DEPRECATED)
#  undef KUSERFEEDBACKWIDGETS_DEPRECATED
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_EXPORT KUSERFEEDBACKWIDGETS_EXPORT
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_NO_EXPORT KUSERFEEDBACKWIDGETS_NO_EXPORT
#elif defined(KUSERFEEDBACKWIDGETS_NO_DEPRECATED_WARNINGS)
#  define KUSERFEEDBACKWIDGETS_DEPRECATED
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_EXPORT KUSERFEEDBACKWIDGETS_EXPORT
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_NO_EXPORT KUSERFEEDBACKWIDGETS_NO_EXPORT
#else
#  define KUSERFEEDBACKWIDGETS_DEPRECATED KUSERFEEDBACKWIDGETS_DECL_DEPRECATED
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_EXPORT KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_EXPORT
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_NO_EXPORT KUSERFEEDBACKWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KUSERFEEDBACKWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KUSERFEEDBACKWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KUSERFEEDBACKWIDGETS_NO_DEPRECATED
#  define KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KUSERFEEDBACK_VERSION
#endif
#ifdef KUSERFEEDBACKWIDGETS_NO_DEPRECATED_WARNINGS
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KUSERFEEDBACKWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KUSERFEEDBACKWIDGETS_DEPRECATED_WARNINGS_SINCE KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KUSERFEEDBACKWIDGETS_DEPRECATED_WARNINGS_SINCE KUSERFEEDBACK_VERSION
#  endif
#endif

#ifndef KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60000
#endif

#ifdef KUSERFEEDBACKWIDGETS_DEPRECATED
#  define KUSERFEEDBACKWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KUSERFEEDBACKWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KUSERFEEDBACKWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KUSERFEEDBACKWIDGETS_EXPORT_H */
